import request from '@/utils/request'

// 查询经营异常名录列表
export function listList(query) {
  return request({
    url: '/crmAbnormalBusinessList/findByPage',
    method: 'get',
    params: query
  })
}

// 查询经营异常名录详细
export function getListData(id) {
  return request({
    url: '/basicData/list/' + id,
    method: 'get'
  })
}

// 新增经营异常名录
export function addList(data) {
  return request({
    url: '/basicData/list',
    method: 'post',
    data: data
  })
}

// 修改经营异常名录
export function updateList(data) {
  return request({
    url: '/basicData/list',
    method: 'put',
    data: data
  })
}

// 删除经营异常名录
export function delList(id) {
  return request({
    url: '/crmAbnormalBusinessList/deleteAll',
    method: 'delete'
  })
}

// 批量删除行政许可
export function delListBatch(ids) {
  console.log(ids);
  return request.post('/crmAbnormalBusinessList/delete',ids)
}