<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="统一社会信用代码/注册号" label-width="200" prop="unifiedSocialCreditCode">
        <el-input
            v-model="queryParams.unifiedSocialCreditCode"
            placeholder="请输入统一社会信用代码/注册号"
            clearable
            @keyup.enter="handleQuery"
        />
      </el-form-item>
<!--      <el-form-item label="登记机关" prop="registrationAuthority">-->
<!--        <el-input-->
<!--            v-model="queryParams.registrationAuthority"-->
<!--            placeholder="请输入登记机关"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
      <el-form-item label="法定代表人" label-width="200" prop="legalRepresentative">
        <el-input
            v-model="queryParams.legalRepresentative"
            placeholder="请输入法定代表人"
            clearable
            @keyup.enter="handleQuery"
        />
      </el-form-item>
<!--      <el-form-item label="列入决定时间" prop="listingDecisionDate">-->
<!--        <el-date-picker clearable-->
<!--                        v-model="queryParams.listingDecisionDate"-->
<!--                        type="date"-->
<!--                        value-format="YYYY-MM-DD"-->
<!--                        placeholder="请选择列入决定时间">-->
<!--        </el-date-picker>-->
<!--      </el-form-item>-->
<!--      <el-form-item label="文号" prop="documentNumber">-->
<!--        <el-input-->
<!--            v-model="queryParams.documentNumber"-->
<!--            placeholder="请输入文号"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="列入原因" prop="reasonForListing">-->
<!--        <el-input-->
<!--            v-model="queryParams.reasonForListing"-->
<!--            placeholder="请输入列入原因"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="数据来源" prop="dataSource">-->
<!--        <el-input-->
<!--            v-model="queryParams.dataSource"-->
<!--            placeholder="请输入数据来源"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
      <el-form-item>
        <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
        <el-button icon="Refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
      <el-form-item>
        <el-row :gutter="10" class="mb8">
          <!--      <el-col :span="1.5">-->
          <!--        <el-button-->
          <!--            type="primary"-->
          <!--            plain-->
          <!--            icon="Plus"-->
          <!--            @click="handleAdd"-->
          <!--            v-hasPermi="['basicData:list:add']"-->
          <!--        >新增</el-button>-->
          <!--      </el-col>-->
          <!--      <el-col :span="1.5">-->
          <!--        <el-button-->
          <!--            type="success"-->
          <!--            plain-->
          <!--            icon="Edit"-->
          <!--            :disabled="single"-->
          <!--            @click="handleUpdate"-->
          <!--            v-hasPermi="['basicData:list:edit']"-->
          <!--        >修改</el-button>-->
          <!--      </el-col>-->
          <el-col :span="1.5">
            <el-popconfirm
                title="你确定清除所有数据？"
                confirm-button-text="是的"
                cancel-button-text="不是"
                :icon="InfoFilled"
                icon-color="#626AEF"
                @confirm="handleDelete"
            >
              <template #reference>
                <el-button
                    type="danger"
                    plain
                    icon="Delete"
                    v-hasPermi="['basicData:license:remove']"
                >清除全表</el-button>
              </template>
            </el-popconfirm>
          </el-col>
          <el-col :span="1.5">
            <el-button
                type="danger"
                plain
                icon="Delete"
                @click="batchDelete"
                v-hasPermi="['basicData:license:remove']"
                :disabled="ids.length === 0"
            >批量删除</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button
                type="warning"
                plain
                icon="Download"
                :disabled="!listListData.length"
                @click="handleExport"
                v-hasPermi="['basicData:list:export']"
            >导出</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="info" plain icon="Upload" @click="handleImport"
                       v-hasPermi="['system:user:import']">导入
            </el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="success" plain icon="Download" @click="downloadTemplate">
              下载导入模版
            </el-button>
          </el-col>
          <!--      <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>-->
        </el-row>
      </el-form-item>
    </el-form>



    <el-table v-loading="loading" :data="listListData" height="650" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
<!--      <el-table-column label="主键" align="center" prop="id" />-->
      <el-table-column label="统一社会信用代码/注册号" align="center" prop="unifiedSocialCreditCode" width="200" />
      <el-table-column label="登记机关" align="center" prop="registrationAuthority" :show-overflow-tooltip='true' />
      <el-table-column label="法定代表人" align="center" prop="legalRepresentative" :show-overflow-tooltip='true' />
      <el-table-column label="列入决定时间" align="center" prop="listingDecisionDate" width="180" :show-overflow-tooltip='true' >
        <template #default="scope">
          <span>{{ parseTime(scope.row.listingDecisionDate, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="状态" align="center" prop="status" :show-overflow-tooltip='true' />
      <el-table-column label="文号" align="center" prop="documentNumber" :show-overflow-tooltip='true' />
      <el-table-column label="列入原因" align="center" prop="reasonForListing" :show-overflow-tooltip='true' />
      <el-table-column label="数据来源" align="center" prop="dataSource" :show-overflow-tooltip='true' />
<!--      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">-->
<!--        <template #default="scope">-->
<!--          <el-button-->
<!--              type="text"-->
<!--              icon="Edit"-->
<!--              @click="handleUpdate(scope.row)"-->
<!--              v-hasPermi="['basicData:list:edit']"-->
<!--          >修改</el-button>-->
<!--          <el-button-->
<!--              type="text"-->
<!--              icon="Delete"-->
<!--              @click="handleDelete(scope.row)"-->
<!--              v-hasPermi="['basicData:list:remove']"-->
<!--          >删除</el-button>-->
<!--        </template>-->
<!--      </el-table-column>-->
    </el-table>

    <div style="position: fixed;bottom: 20px;right: 10px;">
      <pagination
          v-show="total>0"
          :total="total"
          v-model:page="queryParams.pageNum"
          v-model:limit="queryParams.pageSize"
          @pagination="getList"
      />
    </div>

    <el-dialog :title="upload.title" v-model="upload.open" width="400px" append-to-body>
      <el-upload ref="uploadRef" :limit="1" accept=".xlsx, .xls" :headers="upload.headers"
                 :action="upload.url + '?updateSupport=' + upload.updateSupport" :disabled="upload.isUploading"
                 :on-progress="handleFileUploadProgress" :on-success="handleFileSuccess" :auto-upload="false" drag>
        <el-icon class="el-icon--upload"><upload-filled /></el-icon>
        <div class="el-upload__text">将文件拖到此处，或<em>点击上传</em></div>
        <template #tip>
          <div class="el-upload__tip text-center">
            <span>仅允许导入xls、xlsx格式文件。</span>
          </div>
        </template>
      </el-upload>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitFileForm">确 定</el-button>
          <el-button @click="upload.open = false">取 消</el-button>
        </div>
      </template>
    </el-dialog>

    <!-- 添加或修改严重违法失信名单对话框 -->
    <el-dialog :title="title" v-model="open" width="500px" append-to-body>
      <el-form ref="listRef" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="统一社会信用代码/注册号" prop="unifiedSocialCreditCode">
          <el-input v-model="form.unifiedSocialCreditCode" placeholder="请输入统一社会信用代码/注册号" />
        </el-form-item>
        <el-form-item label="登记机关" prop="registrationAuthority">
          <el-input v-model="form.registrationAuthority" placeholder="请输入登记机关" />
        </el-form-item>
        <el-form-item label="法定代表人" prop="legalRepresentative">
          <el-input v-model="form.legalRepresentative" placeholder="请输入法定代表人" />
        </el-form-item>
        <el-form-item label="列入决定时间" prop="listingDecisionDate">
          <el-date-picker clearable
                          v-model="form.listingDecisionDate"
                          type="date"
                          value-format="YYYY-MM-DD"
                          placeholder="请选择列入决定时间">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="文号" prop="documentNumber">
          <el-input v-model="form.documentNumber" placeholder="请输入文号" />
        </el-form-item>
        <el-form-item label="列入原因" prop="reasonForListing">
          <el-input v-model="form.reasonForListing" placeholder="请输入列入原因" />
        </el-form-item>
        <el-form-item label="数据来源" prop="dataSource">
          <el-input v-model="form.dataSource" placeholder="请输入数据来源" />
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="List">
import {listList, getListData, delList, addList, updateList, delListBatch} from "@/api/basicData/list2";
import {reactive} from "vue";
import {getToken} from "@/utils/auth";
import {ElMessage} from "element-plus";
import {likeQueryMethod} from "@/utils/likeQueryMethod";

const { proxy } = getCurrentInstance();

const listListData = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");

const upload = reactive({
  // 是否显示弹出层（用户导入）
  open: false,
  // 弹出层标题（用户导入）
  title: '',
  // 是否禁用上传
  isUploading: false,
  // 设置上传的请求头部
  headers: {Authorization: getToken()},
  // 上传的地址
  url: import.meta.env.VITE_APP_BASE_API + '/crmSeriouslyIllegalAndDishonestList/importData'
})
const handleFileSuccess = (e)=>{
  if(e.code == 200){
    ElMessage({
      type:"success",
      message:e.msg
    })
    getList()
    proxy.$refs['uploadRef']?.clearFiles()
  }else {
    ElMessage({
      type:"error",
      message:e.msg
    })
    proxy.$refs['uploadRef']?.clearFiles()
  }
}
function submitFileForm() {
  proxy.$refs['uploadRef'].submit()
  upload.open = false;
  // setTimeout(getList,1000)
}
function handleImport() {
  upload.open = true
  // let toServerObj = likeQueryMethod('unified_social_credit_code', queryParams.value.unifiedSocialCreditCode, queryParams.value.pageNum, queryParams.value.pageSize,'legal_representative',queryParams.value.legalRepresentative);
  // listList(toServerObj).then(res=>{
  //   if(res.records.length >0){
  //     ElMessage({
  //       type:'warning',
  //       message:'当前已经有数据，请删除后再导入'
  //     })
  //     return
  //   }else {
  //     upload.title = '用户导入'
  //     upload.open = true
  //   }
  // })
}

const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 20,
    unifiedSocialCreditCode: '',
    registrationAuthority: null,
    legalRepresentative: null,
    listingDecisionDate: null,
    status: null,
    documentNumber: null,
    reasonForListing: null,
    dataSource: null,
  },
  rules: {
    unifiedSocialCreditCode: [
      { required: true, message: "统一社会信用代码/注册号不能为空", trigger: "blur" }
    ],
  }
});

const { queryParams, form, rules } = toRefs(data);

/** 查询严重违法失信名单列表 */
function getList() {
  loading.value = true;
  let toServerObj = likeQueryMethod('unified_social_credit_code', queryParams.value.unifiedSocialCreditCode, queryParams.value.pageNum, queryParams.value.pageSize,'legal_representative',queryParams.value.legalRepresentative);
  listList(toServerObj).then(response => {
    listListData.value = response.records;
    total.value = response.total;
    loading.value = false;
  });
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    id: null,
    unifiedSocialCreditCode: '',
    registrationAuthority: null,
    legalRepresentative: null,
    listingDecisionDate: null,
    status: "0",
    documentNumber: null,
    reasonForListing: null,
    dataSource: null,
    createTime: null,
    updateTime: null
  };
  proxy.resetForm("listRef");
}

/** 搜索按钮操作 */
function handleQuery() {
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map(item => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "添加严重违法失信名单";
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const id = row.id || ids.value
  getListData(id).then(response => {
    form.value = response.data;
    open.value = true;
    title.value = "修改严重违法失信名单";
  });
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["listRef"].validate(valid => {
    if (valid) {
      if (form.value.id != null) {
        updateList(form.value).then(response => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addList(form.value).then(response => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
async function handleDelete(row) {
  const res = await delList();
  if(res.code == 200){
    ElMessage({
      type:'success',
      message:'删除成功'
    })
    getList();
  }
  // const ids = row.id || ids.value;
  // proxy.$modal.confirm('是否确认删除严重违法失信名单编号为"' + ids + '"的数据项？').then(function() {
  //   return delList(ids);
  // }).then(() => {
  //   getList();
  //   proxy.$modal.msgSuccess("删除成功");
  // }).catch(() => {});
}

/**
 * 批量删除
 */
const batchDelete = (row)=>{
  const idsToS = row.id || ids.value;
  proxy.$modal.confirm('是否确认删除这'+idsToS.length+'条的数据项？').then(function() {
    return delListBatch(toRaw(idsToS));
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}

/** 导出按钮操作 */
function handleExport() {
  proxy.download('crmSeriouslyIllegalAndDishonestList/exportData', {
    ...queryParams.value
  }, `严重违法失信名单_${new Date().getTime()}.xlsx`)
}

const downloadTemplate = ()=>{
  proxy.download('crmSeriouslyIllegalAndDishonestList/getUploadTemplate',{}, `严重违法失信名单模板.xlsx`)
}

getList();
</script>
